@@ -106,7 +106,7 @@ class NetcatsTool(Tool):
                 state = 'FIXME-' + errmsg.replace(' ', '-')
                 self.stderr = True
         except gevent.GreenletExit:
-            assert not 'this is should not happen'
+            state = 'filtered'
 
         done = False
         stdin = self._stdin_pipe[0]
